@@ -16,4 +16,4 @@ finally:
     del get_distribution, DistributionNotFound
 
 
-from qary.init import maybe_download  # noqa
+# from qary.init import maybe_download  # noqa
