@@ -19,7 +19,7 @@ except ImportError:  # python <3.7
     from collections import Mapping
 
 
-from ..constants import WELCOME_STATE_NAME
+from ..chat.v2 import WELCOME_STATE_NAME
 from ..constants import DEFAULT_BOT_USERNAME
 
 
@@ -68,7 +68,7 @@ def get_nxt_cndn_match_mthd_dict(nxt_cndn):
     return nxt_cndn_match_mthd_dict
 
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 ####################################################################
