@@ -7,7 +7,7 @@ from qary.etl.utils import normalize_name  # , normalize_wikititle, slugify
 from qary.etl.nesting import default_normalizer
 import yaml
 
-from qary.constants import DATA_DIR, DOMAINS
+from qary.config import DATA_DIR, DOMAINS
 
 try:
     from collections.abc import Mapping
@@ -15,9 +15,9 @@ except ImportError:  # python <3.7
     from collections import Mapping
 
 
-from qary.constants import WELCOME_STATE_NAME, FINISH_STATE_NAME, DEFAULT_STATE_NAME
-from qary.constants import DEFAULT_BOT_USERNAME, EXIT_STATE_NAME
-# from qary.constants import EXIT_STATE_TURN_DICT, EXIT_BOT_STATEMENTS
+from qary.chat.v2 import WELCOME_STATE_NAME, FINISH_STATE_NAME, DEFAULT_STATE_NAME
+from qary.config import DEFAULT_BOT_USERNAME, EXIT_STATE_NAME
+# from qary.config import EXIT_STATE_TURN_DICT, EXIT_BOT_STATEMENTS
 
 
 # FIXME: make this a config option and dont default to a test file
@@ -50,7 +50,7 @@ def normalize_wikititle(title: str):
     return re.sub(r'[\s_]+', ' ', title).strip().lower()
 
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 ####################################################################
@@ -214,9 +214,8 @@ def lod_replace(unclean, mapping, replace_values=True, replace_keys=False,
 def load_dialog_turns(datafile):
     """Load datafile (currently yml) and create a turns datastructure
 
-    >>> datafile = Path(DATA_DIR) / 'yes_no/intern_quiz.yml'
+    >>> datafile = Path(DATA_DIR) / 'tests' / 'intern_quiz.yml'
     >>> load_dialog_turns(datafile) # doctest: +ELLIPSIS
-    [{'state': '__default__', 'bot_next_condition':...
     """
     datafile = Path(datafile)
     if not datafile.exists():
