@@ -13,18 +13,28 @@ from collections import abc
 import io
 import logging
 from pathlib import Path
-from qary.constants import DATA_DIR
+from qary.init import maybe_download
 import time
 import yaml
 
 import numpy as np
 import pandas as pd
 
-log = logging.getLogger(__name__)
-log.setLevel(logging.DEBUG)
+log = logging.getLogger('qary')
+logging.basicConfig(level=logging.DEBUG)
 
+WELCOME_STATE_NAME = '__WELCOME__'
 DEFAULT_LANG = 'en'
-DIALOG_TREE_FILEPATH = Path(DATA_DIR) / 'chat' / 'moia-poly-dialog-tree-simplified-chinese.v4.dialog.yml'
+EXAMPLE_DIALOG_TREE_FILEPATH = maybe_download(filename=Path('chat/example-multilingual.v3.dialog.yml'))
+EMPTY_DIALOG_TREE = pd.Series({
+    WELCOME_STATE_NAME:
+        {'name': WELCOME_STATE_NAME,
+         'actions':
+            {'en': "I have nothing to say ;-) (My v3 dialog tree is empty)"},
+         'triggers':
+            {'en': {"": WELCOME_STATE_NAME}},
+         }
+})
 
 # TODO see ISO_LANG codes in constants for nessvec or qary package
 LANGS = {
@@ -101,15 +111,15 @@ def update_state_list_with_buttons(states):
     return states
 
 
-def coerce_dialog_tree_series(states: (str, dict, Path, io.TextIOWrapper, pd.Series, list, np.ndarray, pd.Series)):
+def coerce_dialog_tree_series(states: (str, Path, abc.Mapping, io.TextIOWrapper, pd.Series, list, np.ndarray, pd.Series)):
     """ Ensure that (yamlfilepath | list) -> dict -> Series """
     if isinstance(states, pd.Series):
         return states
     if isinstance(states, (str, Path)):
         with Path(states).open() as fin:
-            states = yaml.full_load(fin)
-    if isinstance(states, io.TextIOWrapper):
-        states = yaml.full_load(states)
+            return coerce_dialog_tree_series(yaml.full_load(fin))
+    if isinstance(states, io.TextIOWrapper):  # opened file mode='rt'
+        return coerce_dialog_tree_series(yaml.full_load(states))
     if isinstance(states, abc.Mapping):
         return pd.Series(states)
     if isinstance(states, (list, np.ndarray)):
@@ -118,14 +128,19 @@ def coerce_dialog_tree_series(states: (str, dict, Path, io.TextIOWrapper, pd.Ser
             index=[s.get('name', str(i)) for (i, s) in enumerate(states)])
         states.index.name = 'name'
         return states
-    raise ValueError(f"Unable to coerce {type(states)} into pd.Series:\n  states={str(states)[:130]}...")
+    if states is None:
+        return EMPTY_DIALOG_TREE
+    raise ValueError(
+        f"Unable to coerce {type(states)} into pd.Series:\n  states={str(states)[:130]}..."
+    )
 
 
-DIALOG_TREE = coerce_dialog_tree_series(states=DIALOG_TREE_FILEPATH)
-DIALOG_TREE_DICT = {node['name']: node for node in DIALOG_TREE}
+EXAMPLE_DIALOG_TREE = coerce_dialog_tree_series(states=EXAMPLE_DIALOG_TREE_FILEPATH)
+EXAMPLE_DIALOG_TREE_DICT = EXAMPLE_DIALOG_TREE.to_dict()
+EXAMPLE_DIALOG_TREE_SERIES = EXAMPLE_DIALOG_TREE
 
 
-def preprocess_dialog_tree_series(states=DIALOG_TREE):
+def preprocess_dialog_tree_series(states=EXAMPLE_DIALOG_TREE):
     """ Ensure that all dialog tree index values are normalized strs: Series.index.str.lower().str.strip()."""
 
     states = coerce_dialog_tree_series(states)
@@ -152,15 +167,11 @@ def preprocess_dialog_tree_series(states=DIALOG_TREE):
     return pd.Series(dict(states_list))
 
 
-# this is the canonical dialog v3 data structure:
-DIALOG_TREE_SERIES = coerce_dialog_tree_series(DIALOG_TREE_FILEPATH)
-
-
 def await_timeout(seconds=0, milliseconds=0):
     time.sleep(seconds + milliseconds / 1000.0)
 
 
-def next_state_context(states=DIALOG_TREE_SERIES, state_name=None, user_text='', **context):
+def next_state_context(states=EXAMPLE_DIALOG_TREE, state_name=None, user_text='', **context):
     r""" Recognize desired state transition trigger and return next_state name
 
       Inputs:
@@ -233,10 +244,15 @@ def next_state_context(states=DIALOG_TREE_SERIES, state_name=None, user_text='',
     return context
 
 
+def on_answer_noop(*args, **kwargs):
+    log.warning('User action was a NOOP!!!!')
+    log.warning(f'  NOOP\nargs: {args}\nkwargs={kwargs}')
+
+
 class Engine:  # Engine(pd.Series)
     """ A state machine designed for managing the dialog for a rule-based chatbot """
 
-    def __init__(self, states=DIALOG_TREE_SERIES, **context):
+    def __init__(self, states=EXAMPLE_DIALOG_TREE, **context):
         self.hist = []
         self.context = {}
         self.states = preprocess_dialog_tree_series(states)
@@ -279,16 +295,18 @@ class Engine:  # Engine(pd.Series)
         return self.context
 
     def normalize_user_text(self, user_text):
-        if isinstance(user_text, str):
-            return user_text.lower().strip()
-        return user_text
+        return(str(user_text).lower().strip())
 
     def do_user_intent(self, **context):
         self.update_context(context)
         user_text = self.context.get('user_text')
         state_name = self.context.get('state_name')
         node = self.states[state_name]
-        triggers = node['triggers']
+        on_answer_functions = node.get('on_answer', [])
+        for fun_name in on_answer_functions:
+            fun = globals().get(fun_name, on_answer_noop)
+            self.update_context(fun.__call__(context))
+        triggers = node.get('triggers', {})
         lang = self.context.get('lang', DEFAULT_LANG)
         intents = triggers[lang]
         user_intent_text = self.normalize_user_text(user_text)
@@ -386,9 +404,9 @@ class Engine:  # Engine(pd.Series)
             elif isinstance(timeout, (float, int)):
                 await_timeout(timeout)
         if new_state_name is None:
-            log.warning(f"No state change was triggered by user_text {user_text} for state_name {node['name']}!")
+            log.error(f"No state change was triggered by user_text {user_text} for state_name {node['name']}!")
             new_state_name = context.get('state_name')
-            log.warning(f"    Remaining in state_name {new_state_name}!")
+            log.error(f"    Remaining in state_name {new_state_name}!")
         self.context = context
         return new_state_name
 
@@ -454,3 +472,25 @@ class Engine:  # Engine(pd.Series)
  'actions_with_buttons': {},
  'iloc': 2}
 """
+
+
+default_dialog_engine = Engine()
+
+
+def extract_lang(context):
+    # state = context.get('state', {})
+    state_name = context.get('state_name', 'unknown-state')
+    context[state_name + '.answer'] = context.get('user_text', '')
+    return context
+
+
+def next_state(state_name='select-language', user_text='English', context=None):
+    """ API example for Greg
+
+    >>> next_state(state_name='select-language', user_text='English')
+    {'state_name': 'selected-language-welcome', 'lang': 'en', 'user_text': 'English', 'select-language.answer': 'English'}
+    """
+    context = {} if context is None else context
+    context['state_name'] = state_name
+    context['user_text'] = user_text
+    return default_dialog_engine.do_user_intent(**context)
