@@ -22,7 +22,8 @@ import yaml
 import numpy as np
 import pandas as pd
 
-import qary.init as conf
+from qary.config import CLI_ARGS, DEFAULT_SKILLS, MAX_TURNS, DEFAULT_CONFIG
+from qary.init import DATA_DIR, BASE_DIR, SRC_DIR, HISTORY_PATH
 from qary.skills.base import normalize_replies, BotReply
 
 __author__ = "see AUTHORS.md and README.md: Travis, Nima, Erturgrul, Aliya, Xavier, Maria, Hobson, ..."
@@ -30,12 +31,11 @@ __copyright__ = "Hobson Lane"
 __license__ = "The Hippocratic License (MIT + *Do No Harm*, see LICENSE.txt)"
 
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 log.info(f'sys.path: {sys.path}')
-log.info(f'conf: {dir(conf)}')
-log.info(f'BASE_DIR: {conf.BASE_DIR}')
-log.info(f'SRC_DIR: {conf.SRC_DIR}')
+log.info(f'BASE_DIR: {BASE_DIR}')
+log.info(f'SRC_DIR: {SRC_DIR}')
 log.info(f'sys.path (after append): {sys.path}')
 from qary.scores.quality_score import QualityScore  # noqa
 
@@ -54,7 +54,7 @@ class CLIBot:
 
     def __init__(
             self,
-            skill_module_names=conf.DEFAULT_SKILLS,
+            skill_module_names=DEFAULT_SKILLS,
             skill_init_kwargs_list=None,
             num_top_replies=None,
             score_kwargs=None):
@@ -86,7 +86,7 @@ class CLIBot:
                 or skill_init_kwargs is None
             ) else dict(skill_init_kwargs)
             self.add_skill(module_name=module_name, **kwargs)
-        self.num_top_replies = conf.DEFAULT_CONFIG['num_top_replies'] if num_top_replies is None else min(
+        self.num_top_replies = DEFAULT_CONFIG['num_top_replies'] if num_top_replies is None else min(
             max(int(num_top_replies), 1), 10000)
         self.repliers = [obj.reply if hasattr(obj, 'reply') else obj for obj in self.skills if obj is not None]
         log.debug(f'Loaded skills: {self.skills}')
@@ -113,7 +113,7 @@ class CLIBot:
         self.skills.extend(new_skill_objs)
         return new_skill_objs
 
-    def log_reply(self, history_path=conf.HISTORY_PATH, *args, **kwargs):
+    def log_reply(self, history_path=HISTORY_PATH, *args, **kwargs):
         if str(history_path).lower().endswith('.json'):
             history = []
             try:
@@ -158,7 +158,7 @@ class CLIBot:
             except Exception as e:
                 log.error(
                     f'Error trying to run {skill.__module__}.reply("{statement}", context={context})')
-                if conf.CLI_ARGS.debug:
+                if CLI_ARGS.debug:
                     raise e
             bot_replies = normalize_replies(bot_replies)
             replies.extend(bot_replies)
@@ -214,21 +214,21 @@ def run_skill():
     global BOT
     if BOT is None:
         BOT = CLIBot(
-            skill_module_names=conf.CLI_ARGS.bots,
-            num_top_replies=conf.CLI_ARGS.num_top_replies,
+            skill_module_names=CLI_ARGS.bots,
+            num_top_replies=CLI_ARGS.num_top_replies,
             score_kwargs=dict(
-                semantic=conf.CLI_ARGS.semantic,
-                spell=conf.CLI_ARGS.spell))
-    if conf.CLI_ARGS.persist:
+                semantic=CLI_ARGS.semantic,
+                spell=CLI_ARGS.spell))
+    if CLI_ARGS.persist:
         print('Type "quit" or "exit" to end the conversation...')
 
-    log.debug(f'FINAL PROCESSED ARGS AFTER INSTANTIATING CLIBot:\n{vars(conf.CLI_ARGS)}\n')
+    log.debug(f'FINAL PROCESSED ARGS AFTER INSTANTIATING CLIBot:\n{vars(CLI_ARGS)}\n')
     return BOT
 
 
 def cli(args,
         exit_commands='exit quit bye goodbye cya hasta seeya'.split(),
-        max_turns=conf.MAX_TURNS):
+        max_turns=MAX_TURNS):
     global BOT
     BOT = run_skill() if BOT is None else BOT
     context = {}
@@ -267,7 +267,7 @@ def cli(args,
                 **context)
             history.append(history_record)
     history = pd.DataFrame(history)
-    history.to_csv(os.path.join(conf.DATA_DIR, 'history.csv'))
+    history.to_csv(os.path.join(DATA_DIR, 'history.csv'))
     return history
 
 
@@ -275,8 +275,8 @@ def main():
     global BOT
     BOT = run_skill() if BOT is None else BOT
     # args = conf.parse_argv(argv=sys.argv)
-    statements = cli(conf.CLI_ARGS)
-    if conf.CLI_ARGS.loglevel >= 50:
+    statements = cli(CLI_ARGS)
+    if CLI_ARGS.loglevel >= 50:
         return
     return statements
 
