@@ -16,26 +16,24 @@ import numpy as np
 import pandas as pd
 import spacy  # noqa
 import configargparse
-from environment import Environment
 import django.conf
 
 from qary import __version__
+from qary.constants import HOME_DIR  # noqa
+from qary.constants import BASE_DIR
 from qary.constants import *  # noqa
 
-# TODO: Do Django SECRET_KEY and any AWS/RASA/DO keys need to be integrated into env here?
-env = Environment(spacy_lang=str, loglevel=int, name=str)
+from dotenv import load_dotenv, dotenv_values
 
+load_dotenv()  # creates os.environ values from `.env` file
+
+env = dotenv_values()
+
+LOGLEVEL = logging.DEBUG
 
-DEFAULT_DIALOG_FILEPATH = Path(DATA_DIR) / 'writing/ogden-script.v2.dialog.yml'
 DIALOG_TREE_END_STATE_NAMES = (None, False, 0, '', ''.encode(), '0', 'none', 'None')
 DIALOG_TREE_END_BOT_STATEMENTS = (None, 'none', )
-WELCOME_STATE_NAME = '__WELCOME__'
-FINISH_STATE_NAME = '__FINISH__'
-DEFAULT_STATE_NAME = '__default__'
 DEFAULT_BOT_USERNAME = 'bot'
-EXIT_STATE_NAME = None
-EXIT_BOT_STATEMENTS = ['Session is already over! Type "quit" to exit or press "Enter" for a new session']
-EXIT_STATE_TURN_DICT = {'state': EXIT_STATE_NAME, DEFAULT_BOT_USERNAME: EXIT_BOT_STATEMENTS}
 
 MIDATA_DOMAINNAME = 'tan.sfo2.digitaloceanspaces.com'
 MIDATA_URL = f'https://{MIDATA_DOMAINNAME}'
@@ -63,7 +61,7 @@ DEFAULT_CONFIG = {
     'score_weights': '{"spell": .25, "semantic": .5}',
     'qa_model': 'albert-large-v2-0.2.0',
 }
-DEFAULT_CONFIG.update(env.parsed)
+DEFAULT_CONFIG.update(dict(env))
 
 LOGLEVELS = [
     logging.DEBUG, logging.INFO, logging.WARNING, logging.ERROR, logging.FATAL]
@@ -72,8 +70,8 @@ LOGLEVEL_NAMES = 'DEBUG INFO WARNING ERROR FATAL'.split()
 LOGLEVEL_ABBREVIATIONS = [s[:4].lower() for s in LOGLEVEL_NAMES]
 LOGLEVEL_ABBR_DICT = dict(zip(LOGLEVEL_ABBREVIATIONS, LOGLEVELS))
 # this is the LOGLEVEL for the top of this file, once CLI_ARGS and .ini file are read, it will change
-LOGLEVEL = getattr(env, 'loglevel', DEFAULT_CONFIG.get('loglevel', logging.WARNING))
-USE_CUDA = getattr(env, 'use_cuda', DEFAULT_CONFIG.get('use_cuda', USE_CUDA))
+LOGLEVEL = env.get('loglevel', DEFAULT_CONFIG.get('loglevel', logging.WARNING))
+USE_CUDA = env.get('use_cuda', DEFAULT_CONFIG.get('use_cuda', USE_CUDA))
 
 
 LOGGING_FORMAT = '%(asctime)s.%(msecs)d %(levelname)-4s %(filename)s:%(lineno)d %(message)s'
@@ -83,9 +81,10 @@ logging.basicConfig(
     format=LOGGING_FORMAT,
     datefmt=LOGGING_DATEFMT,
     level=LOGGING_LEVEL)
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 root_logger = logging.getLogger()
 
+log.info(f'Running {__name__} version {__version__} ...')
 
 # TZ constants
 DEFAULT_TZ = timezone('UTC')
@@ -107,6 +106,35 @@ PUNC = str(string.punctuation)
 COUNT_NAMES = ['count', 'cnt', 'number', 'num', '#', 'frequency', 'probability', 'prob', 'occurences']
 # 4 types of
 
+BIG_DATASETS_MANIFEST_URL = 'https://gitlab.com/tangibleai/qary/-/raw/main/src/qary/data/datasets.yml?inline=false'
+log.debug(f'BIG_DATASETS_MANIFEST_URL={BIG_DATASETS_MANIFEST_URL}')
+
+HOME_DATA_DIR_NAME = '.qary-data'
+HOME_DATA_DIR = HOME_DIR / HOME_DATA_DIR_NAME
+TESTS_DIR = HOME_DATA_DIR / 'tests'
+
+DATA_DIR = HOME_DATA_DIR
+log.info(f'DATA_DIR=HOME_DATA_DIR={HOME_DATA_DIR}')
+
+# DEFAULT_V2_DIALOG_FILEPATH = Path(DATA_DIR) / 'writing/ogden-script.v2.dialog.yml'
+
+
+def create_test_file(filename=None, parent=TESTS_DIR):
+    return create_filepath(filename=filename, parent=parent)
+
+
+def create_data_filepath(filename=None, parent=HOME_DATA_DIR):
+    if not filename:
+        dt = datetime.datetime.now()
+        filename = (f'{dt.year:04d}-{dt.month:02d}-{dt.day:02d}'
+                    f'_{dt.hour:02d}-{dt.minute:02d}-{dt.second:02d}'
+                    f'.{dt.microsecond:06d}')
+    filepath = Path(parent) / str(filename)
+    if not filepath.parent.is_dir():
+        filepath.parent.mkdir(exist_ok=True, parent=True)
+    filepath.open('w').close()
+    return filepath
+
 
 # FIXME: functions like this should not be in constants.py
 def parse_args(args):
@@ -122,10 +150,6 @@ def parse_args(args):
     parser = configargparse.ArgParser(
         default_config_files=[
             '~/qary.ini',
-            # '~/qary.ini',
-            # '~/nlpiabot.ini',
-            # '~/nlpia.ini',
-            # os.path.join(BASE_DIR, '*.ini'),
             os.path.join(DATA_DIR, '*.ini'),
         ],
         description="Command line bot application. Try `$ bot how do you work?`")
@@ -343,7 +367,7 @@ try:
 except Exception as e:  # noqa
     log.info(e)
     log.info('Unable to parse command line arguments. Are you trying to import this into gunicorn?')
-    # Workaround for the bug when Django app tries to import qary.constants:
+    # Workaround for the bug when Django app tries to import qary.config:
     # `usage: gunicorn [-h] [-c CONFIG] ... gunicorn: error: unrecognized arguments
     CLI_ARGS = vars(parse_argv(argv=[]))
 
@@ -351,7 +375,7 @@ except Exception as e:  # noqa
 LOGLEVEL = CLI_ARGS.loglevel or LOGLEVEL
 
 
-# handler = logging.handlers.TimedRotatingFileHandler(os.path.join(LOG_DIR, 'qary.constants.log'), when='midnight')
+# handler = logging.handlers.TimedRotatingFileHandler(os.path.join(LOG_DIR, 'qary.config.log'), when='midnight')
 # handler.setLevel(logging.INFO)
 # log.addHandler(handler)
 
@@ -429,11 +453,13 @@ def set_django_settings(settings=None):
 django_settings = set_django_settings()
 
 
-uri_schemes_popular = ['chrome-extension', 'example', 'content', 'bitcoin',
-                       'telnet', 'mailto',
-                       'https', 'gtalk',
-                       'http', 'smtp', 'feed',
-                       'udp', 'ftp', 'ssh', 'git', 'apt', 'svn', 'cvs']
+uri_schemes_popular = ['http', 'https', 'telnet', 'mailto',
+                       'udp', 'ftp', 'ssh', 'git', 'apt', 'svn', 'cvs', 'hg',
+                       'smtp', 'feed',
+                       'example', 'content',
+                       'gtalk', 'chrome-extension',
+                       'bitcoin'
+                       ]
 
 # these may not all be the sames isinstance types, depending on the env
 FLOAT_TYPES = tuple([t for t in set(np.sctypeDict.values()) if t.__name__.startswith('float')] + [float])
