@@ -10,7 +10,7 @@ import multiprocessing
 from collections import Counter
 
 from qary import __version__
-from qary import constants
+from qary import init
 from qary.etl.netutils import download_if_necessary, upload_to_digitalocean
 from qary.qa.qa_datasets import get_bot_accuracies, load_qa_dataset
 
@@ -19,14 +19,14 @@ def accuracy_report(*skills, scored_qa_pairs=None, upload=True):
     """  get_bot_accuracies() on list of skills and appends to previous results, uploading copy to digitalocean
 
     FIXME: qa skill is broke because transformers and torch upgraded
-    >> filepath = pathlib.Path(constants.DATA_DIR, 'testsets', 'dialog', 'qa-tiny-2020-05-24.json')
+    >> filepath = pathlib.Path(init.DATA_DIR, 'testsets', 'dialog', 'qa-tiny-2020-05-24.json')
     >> scored_qa_pairs=load_qa_dataset(filepath)
     >> from qary.skills import qa
     >> accuracy_report(qa, scored_qa_pairs=scored_qa_pairs, upload=False)
     """
 
     if not scored_qa_pairs:
-        scored_qa_pairs_path = pathlib.Path(constants.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.json')
+        scored_qa_pairs_path = pathlib.Path(init.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.json')
         scored_qa_pairs = load_qa_dataset(scored_qa_pairs_path)
     for skill in skills:
         file_name = 'accuracy_report.gz'
@@ -73,8 +73,8 @@ def accuracy_report(*skills, scored_qa_pairs=None, upload=True):
             }
         ]
 
-        gzip_report_filepath = pathlib.Path(constants.DATA_DIR, 'testsets', file_name)
-        gzip_summary_report = pathlib.Path(constants.DATA_DIR, 'testsets', "summary_accuracy_report.gz")
+        gzip_report_filepath = pathlib.Path(init.DATA_DIR, 'testsets', file_name)
+        gzip_summary_report = pathlib.Path(init.DATA_DIR, 'testsets', "summary_accuracy_report.gz")
         qa_filepath = download_if_necessary('accuracy_report')
         summary_filepath = download_if_necessary('summary_accuracy_report')
 
@@ -109,19 +109,20 @@ def accuracy_report(*skills, scored_qa_pairs=None, upload=True):
             digital_ocean_path_and_newfolders = 'public/nlp/qary/accuracy_reports'
             new_name_file_to_upload = file_name
             upload_to_digitalocean(file_to_upload, name_of_space, digital_ocean_path_and_newfolders, new_name_file_to_upload)
-            gzip_report_filepath = pathlib.Path(constants.DATA_DIR, 'testsets', file_name).unlink()
+            gzip_report_filepath = pathlib.Path(init.DATA_DIR, 'testsets', file_name).unlink()
 
             file_to_upload = str(gzip_summary_report)
             new_name_file_to_upload = "summary_accuracy_report.gz"
             upload_to_digitalocean(file_to_upload, name_of_space, digital_ocean_path_and_newfolders, new_name_file_to_upload)
-            gzip_summary_report = pathlib.Path(constants.DATA_DIR, 'testsets', "summary_accuracy_report.gz").unlink()
+            gzip_summary_report = pathlib.Path(init.DATA_DIR, 'testsets', "summary_accuracy_report.gz").unlink()
 
 
 def gzip_decompress_decode_load_json(GZIP_FILEPATH):
     """opens gzip file decompresses decodes and returns object
 
-    >>> GZIP_FILEPATH = pathlib.Path(constants.DATA_DIR, 'testsets', 'unit_test_data.gz')
-    >>> gzip_decompress_decode_load_json(GZIP_FILEPATH)
+    >>> GZIP_FILEPATH = init.DATA_DIR / 'tests' / 'unit_test_data.gz'
+
+    >> gzip_decompress_decode_load_json(GZIP_FILEPATH)
     {'Hello World': 42}
     """
 
