@@ -29,9 +29,10 @@ from pathlib import Path
 import subprocess
 import yaml
 
-from qary.constants import DATA_DIR, BASE_DIR, MAX_LEN_FILEPATH
+from qary.config import DATA_DIR, BASE_DIR, MAX_LEN_FILEPATH
+from qary.init import maybe_download
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('qary')
 
 
 def url_filename(url):
@@ -142,8 +143,9 @@ def ensure_open(f, mode='r'):
     TODO: try to read a gzip rather than relying on gz extension, likewise for zip and other formats
     TODO: monkey patch the file so that .write_bytes=.write and .write writes both str and bytes
 
-    >>> fn = os.path.join(DATA_DIR, 'unittests', 'wsj_pugnlp.detector_morse.Detector.json.gz')
-    >>> fp = ensure_open(fn)
+    >>> fn = maybe_download(
+    ...     filename='tests/wsj_pugnlp.detector_morse.Detector.json.gz')
+    >>> fp = ensure_open(DATA_DIR / fn)
     >>> fp
     <gzip _io.BufferedReader name='...qary/data/unittests/wsj_pugnlp.detector_morse.Detector.json.gz' 0x...>
     >>> fp.closed
@@ -172,17 +174,28 @@ def ensure_open(f, mode='r'):
     ValueError: I/O operation on closed file.
     """
     fin = f
-    if isinstance(f, (str, bytes)):
-        if len(f) <= MAX_LEN_FILEPATH:
-            f = find_filepath(f) or f
-            if f and (not hasattr(f, 'seek') or not hasattr(f, 'readlines')):
-                if f.lower().endswith('.gz'):
-                    return gzip.open(f, mode=mode)
-                return open(f, mode=mode)
-            f = fin  # reset path in case it is the text that needs to be opened with StringIO
-        else:
-            f = io.StringIO(f)
-    elif f and getattr(f, 'closed', None):
+    if isinstance(f, io.TextIOWrapper):
+        if not f.closed:
+            return f
+        return ensure_open(Path(f.name), mode=mode)
+    if isinstance(f, Path):
+        f = maybe_download(filename=f)
+        return Path(f).open(mode=mode)
+    if isinstance(f, bytes):
+        return ensure_open(f.decode(), mode=mode)
+    if isinstance(f, str):
+        if len(f) > MAX_LEN_FILEPATH:
+            return io.StringIO(f)
+        # assume it's a path rather than data for StreamIO:
+        f = maybe_download(filename=Path(f))
+        f = find_filepath(f) or f
+        if f and (not hasattr(f, 'seek') or not hasattr(f, 'readlines')):
+
+            if f.lower().endswith('.gz'):
+                return gzip.open(f, mode=mode)
+            return ensure_open(Path(fin), mode=mode)
+        return ensure_open(Path(f.name), mode=mode)  # reset path in case it is the text that needs to be opened with StringIO
+    if f and getattr(f, 'closed', None):
         if hasattr(f, '_write_gzip_header'):
             return gzip.open(f.name, mode=mode)
         else:
