@@ -23,7 +23,7 @@ except ImportError:  # python <3.7
 import copy
 
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 def dict_merge(dct, merge_dct):
