@@ -9,7 +9,7 @@ import numpy as np
 import pandas as pd
 from slugify import slugify  # noqa
 
-from qary.constants import DATA_DIR
+from qary.config import DATA_DIR
 from qary.spacy_language_model import nlp
 
 
