@@ -7,8 +7,8 @@ from collections import abc
 from tqdm import tqdm
 import wikipedia as wiki
 
-log = logging.getLogger(__name__)
-log.setLevel(logging.INFO)
+log = logging.getLogger('qary')
+logging.basicConfig(level=logging.INFO)
 
 PROSOCIAL_PAGE_TITLES = [
     "Prosocial behavior",
@@ -22,6 +22,7 @@ PROSOCIAL_PAGE_TITLES = [
     "Discernment",
     "Altruism",
     "Omnibenevolence",
+    "Social market economy"
 ]
 
 
