@@ -4,16 +4,16 @@ import pathlib
 import sys
 import yaml
 
-from qary import constants
+from qary import init
 
-YAML_FILEPATH = pathlib.Path(constants.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.yml')
-JSON_FILEPATH = pathlib.Path(constants.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.json')
+YAML_FILEPATH = pathlib.Path(init.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.yml')
+JSON_FILEPATH = pathlib.Path(init.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.json')
 
 
 def yaml_to_json(yamlpath=YAML_FILEPATH, jsonpath=JSON_FILEPATH):
     r"""converts yaml to json file
 
-    >>> yamlpath = pathlib.Path(constants.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.yml')
+    >>> yamlpath = pathlib.Path(init.DATA_DIR, 'testsets', 'dialog', 'qa-2020-04-25.yml')
     >>> jsonpath = yamlpath.parent / (yamlpath.name[:-3] + 'json')
     >>> yaml_to_json(yamlpath=yamlpath, jsonpath=jsonpath)
     PosixPath('.../testsets/dialog/qa-2020-04-25.json')
