@@ -1,37 +1,97 @@
 # init.py
-from urllib.request import urlretrieve
-from pathlib import Path
-import logging
 import json
+import logging
+from pathlib import Path
+import shutil
+from urllib.request import urlretrieve
+from urllib.parse import urljoin
 
 import pandas as pd
 
-from qary.config import *
+from qary.config import BASE_DIR, HOME_DATA_DIR, DATA_DIR  # noqa
+from qary.config import SRC_DIR, SRC_DATA_DIR  # noqa
+from qary.config import uri_schemes_popular  # noqa
+
 # from qary.etl.netutils import DownloadProgressBar  # noqa
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 DATA_URL_PREFIX = 'https://gitlab.com/tangibleai/qary/-/raw/main/src/qary/data/'
 DATA_URL_SUFFIX = '?inline=false'
-DATA_FILENAMES = [
-    'datasets.yml',
+INIT_DATA_FILENAMES = [
+    'chat/example-multilingual.v3.dialog.yml',
     'constants/nltk_stopwords_english.json',
     'constants/tlds-from-iana.csv',
     'constants/uri-schemes.xhtml.csv',
+    'datasets.yml',
     'downloadable_bigdata_directory.yml',
     'eliza_doctor.txt',
+    # 'chat/moia-poly-dialog-tree-simplified-chinese.v3.dialog.yml',
+    'rap/rap_corpus.txt',
+    'tests/dialog_parser.v2.dialog.yml',
+    'testsets/unit_test_data.json',
+    'log/README'
 ]
+# cp: overwrite '/home/hobs/.qary-data.bak/chat/example-multilingual.v3.dialog.yml'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/constants/nltk_stopwords_english.json'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/constants/tlds-from-iana.csv'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/constants/uri-schemes.xhtml.csv'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/datasets.yml'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/doctest-save-hashes.uint64.npy.gz'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/eliza_doctor.txt'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/rap/rap_corpus.txt'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/tests/dialog_parser.v2.dialog.yml'? y
+
+# FIXME: doesn't seem to be created when you start with empty ~/.qary-data dir 'log/README'
+# these created by pytest during doctests etc
+# cp: overwrite '/home/hobs/.qary-data.bak/downloadable_bigdata_directory.yml'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/history.yml'? y
+# cp: overwrite '/home/hobs/.qary-data.bak/tests/dialog.txt'? y
 
 
-def maybe_download(url, filename=None, destination_dir=HOME_DATA_DIR, expected_bytes=None, force=False):
+def maybe_download(
+        url=None, filename=None, filepath=None,
+        destination_dir=None, expected_bytes=None,
+        force=False):
     """ Download a file only if it has not yet been cached locally in ~/.qary-data/ HOME_DATA_DIR
+    """
+    assert filepath is None or filename is None, f"Cannot specify both filepath='{filepath}' and filename='{filename}', they are synonymous."
+    filename = filepath if filename is None else filename
+    log.info(f'filename: {filename}')
+    src_filepath = SRC_DATA_DIR / filename
+    log.info(f'src_filepath: {src_filepath}')
+    home_filepath = HOME_DATA_DIR / filename
+    log.info(f'home_filepath: {home_filepath}')
+    log.info(f'src_filepath.is_file(): {src_filepath.is_file()}')
+    if not home_filepath.parent.is_dir():
+        home_filepath.parent.mkdir(exist_ok=True, parents=True)
+    if filename and src_filepath.is_file():
+        if home_filepath.is_file():
+            return home_filepath
 
-    FIXME: meld these same changes with nlpia2.init.maybe_download """
-    if filename is None:
+        log.debug(f'Need to copy {src_filepath} to {home_filepath}')
+        assert src_filepath.is_file()
+        shutil.copy(
+            src=src_filepath,
+            dst=home_filepath,
+            follow_symlinks=True)
+        assert home_filepath.is_file()
+        return home_filepath
+
+    if url is None:
+        try:
+            url = urljoin(str(DATA_URL_PREFIX), str(filename))
+        except ValueError:
+            log.error('maybe_download() positional arguments deprecated. please specify url or filename (relative file path)')
+            filename, url = url, None
+
+    if filename is None and url is not None:
         filename = url.split('/')[-1].split('?')[0].split(':')[-1]
-    destination_dir = Path(destination_dir)
+    if destination_dir is None:
+        destination_dir = Path(HOME_DATA_DIR)
     filepath = destination_dir / filename
+    destination_dir, filename = filepath.parent, filepath.name
 
     if not destination_dir.exists():
         destination_dir.mkdir(parents=True, exist_ok=True)  # FIXME add , reporthook=DownloadProgressBar())
@@ -42,9 +102,9 @@ def maybe_download(url, filename=None, destination_dir=HOME_DATA_DIR, expected_b
         filepath.write_bytes(local_data_filepath.read_bytes())
 
     if force or not filepath.is_file():
-        log.info(f"Downloading: {url} to {filepath}")
+        log.error(f"Downloading: {url} to {filepath}")
         filepath, _ = urlretrieve(str(url), str(filepath))
-        log.info(f"Finished downloading '{filepath}'")
+        log.error(f"Finished downloading '{filepath}'")
 
     statinfo = Path(filepath).stat()
 
@@ -60,16 +120,23 @@ def maybe_download(url, filename=None, destination_dir=HOME_DATA_DIR, expected_b
     return filepath
 
 
-for relpath in DATA_FILENAMES:
-    relpath = Path(relpath)
-    destination_dir = DATA_DIR / relpath.parent
-    url = DATA_URL_PREFIX + str(relpath) + DATA_URL_SUFFIX
-    print('url', 'relpath', 'relpath.name')
-    print(url, relpath, relpath.name)
-    maybe_download(url=url, filename=relpath.name, destination_dir=destination_dir)
+def download_important_data(filenames=INIT_DATA_FILENAMES, force=False):
+    """ Iterate through the important data filenames and download them from gitlab to a local cache """
+    for i, relpath in enumerate(filenames):
+        relpath = Path(relpath)
+        destination_dir = HOME_DATA_DIR / relpath.parent
+        url = DATA_URL_PREFIX + str(relpath) + DATA_URL_SUFFIX
+        log.debug(f'url={url}')
+        log.debug(f'relpath={relpath}')
+        log.debug(f'relpath.name={relpath.name}')
+        maybe_download(url=url, filename=relpath.name, destination_dir=destination_dir)
+
+
+download_important_data(filenames=INIT_DATA_FILENAMES)
 
 # shutil.copytree(src=QARY_DATA_DIR, dst=conf.DATA_DIR, dirs_exist_ok=True)
 
+
 LOG_DIR = Path(DATA_DIR) / 'log'
 CONSTANTS_DIR = Path(DATA_DIR) / 'constants'
 HISTORY_PATH = Path(DATA_DIR) / 'history.yml'
