@@ -42,7 +42,7 @@ from qary.qa.utils import (
     # get_best_predictions_extended,
 )
 
-from qary.constants import USE_CUDA
+from qary.config import USE_CUDA
 
 QABOTS_ARGS = {
     'output_dir': '',
