@@ -25,7 +25,7 @@ def whitespace_tokenize(s):
 # from tensorboardX import SummaryWriter
 
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger('qary')
 
 
 class InputExample(object):
