@@ -18,10 +18,11 @@ import os
 import re
 # import regex
 import string
-from qary.init import DATA_DIR, APOSTROPHE_CHARS
+from qary.config import APOSTROPHE_CHARS
+from qary.init import DATA_DIR
 from qary.init import tld_iana, tld_popular, uri_schemes_iana, uri_schemes_popular
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 #####################################################################################
