@@ -1,7 +1,7 @@
 import logging
 from qary import spacy_language_model
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 nlp = spacy_language_model.nlp
 
 try:
