@@ -4,7 +4,7 @@ import random
 import re
 # from collections import namedtuple
 
-from qary.constants import DATA_DIR
+from qary.config import DATA_DIR
 from qary.skills.base import BotReply
 
 # python 2/3 compatibility
@@ -16,7 +16,7 @@ except NameError:
 
 ELIZA_PATH = os.path.join(DATA_DIR, 'eliza_doctor.txt')
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 logging.basicConfig()
 
 
@@ -267,6 +267,7 @@ class Skill:
     def __init__(self):
         self.eliza = Eliza()
         self.eliza.load(ELIZA_PATH)
+        self.welcome_message = "Hi! I'm Eliza, an amateur therapist. How are you feeling?"
 
     def reply(self, statement, context=None):
         """ Chatbot entry point to generate conversational responses to a user question or statement
@@ -280,6 +281,8 @@ class Skill:
         [BotReply(confidence=0.5, text="I'm not sure I understand you fully."...
         """
         responses = []
+        if statement is None:
+            return [self.welcome_message, 1.0]
         bot_statement = self.eliza.respond(statement)
         responses.append(BotReply(
             confidence=0.5,
