@@ -1,14 +1,13 @@
 """ Rule-based chatbot (FSM) for assisting Roman History students """
 import logging
-import os
 from pathlib import Path
 import yaml
 from copy import deepcopy
 
-from qary.constants import DATA_DIR
-from qary.constants import FINISH_STATE_NAME, EXIT_STATE_NAME, DEFAULT_STATE_NAME
-from qary.constants import DEFAULT_BOT_USERNAME, EXIT_BOT_STATEMENTS, EXIT_STATE_TURN_DICT
-from qary.constants import WELCOME_STATE_NAME
+from qary.config import DATA_DIR
+from qary.config import FINISH_STATE_NAME, EXIT_STATE_NAME, DEFAULT_STATE_NAME
+from qary.config import DEFAULT_BOT_USERNAME, EXIT_BOT_STATEMENTS, EXIT_STATE_TURN_DICT
+from qary.chat.v2 import WELCOME_STATE_NAME
 from qary.etl.nesting import lod_replace
 from qary.etl.utils import normalize_wikititle as default_normalizer
 from qary.chat.dialog_managers import DialogManager
@@ -17,18 +16,18 @@ dialog_manager = DialogManager()
 # from qary.chat.dialog import TurnsPreparation
 
 # FIXME: make this a config option and dont default to a test file
-DEFAULT_QUIZ = os.path.join(DATA_DIR, 'writing/historybot-script.v2.dialog.yml')
+DEFAULT_QUIZ = DATA_DIR / 'writing' / 'historybot-script.v2.dialog.yml'
 DIALOG_TREE_END_STATE_NAMES = (None, False, 0, '', ''.encode(), '0', 'none', 'None')
 DIALOG_TREE_END_BOT_STATEMENTS = (None, 'none', )
 
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 def load_dialog_turns(datafile):
     """Load datafile (currently yml) and create a turns datastructure
 
-    >>> datafile = os.path.join(DATA_DIR, 'yes_no/intern_quiz.yml')
+    >>> datafile = DATA_DIR / 'yes_no' / 'intern_quiz.yml'
     >>> load_dialog_turns(datafile) # doctest: +ELLIPSIS
     [{'state': '__default__',...
     """
