@@ -2,22 +2,22 @@
 import logging
 from pathlib import Path
 
-from qary.constants import DATA_DIR
+from qary.config import DATA_DIR
 from qary.skills.base import ContextBaseSkill
 from qary.chat.dialog import TurnsPreparation, compose_statement, load_dialog_turns
 from qary.chat.intents import Intents
 from qary.chat.understanders import check_match
 from qary.chat.dialog import get_nxt_cndn_match_mthd_dict
 
-from qary.constants import DIALOG_TREE_END_STATE_NAMES
-from qary.constants import DIALOG_TREE_END_BOT_STATEMENTS
+from qary.config import DIALOG_TREE_END_STATE_NAMES
+from qary.config import DIALOG_TREE_END_BOT_STATEMENTS
 
-from qary.constants import WELCOME_STATE_NAME
-from qary.constants import DEFAULT_BOT_USERNAME
-from qary.constants import EXIT_STATE_TURN_DICT
-from qary.constants import EXIT_BOT_STATEMENTS
+from qary.chat.v2 import WELCOME_STATE_NAME
+from qary.config import DEFAULT_BOT_USERNAME
+from qary.config import EXIT_STATE_TURN_DICT
+from qary.config import EXIT_BOT_STATEMENTS
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 class Skill(ContextBaseSkill):
