@@ -5,9 +5,9 @@ from qary.chat.v3 import Engine
 from qary.skills.base import normalize_replies, ContextBaseSkill
 
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
-dialog_enging = Engine()
+# engine = Engine()
 
 
 class Skill(ContextBaseSkill):
@@ -21,15 +21,15 @@ class Skill(ContextBaseSkill):
     def __init__(self, *args, **kwargs):
         """ Load the v3.dialog.yaml file to initialize the dialog state machine (dialog engine) """
         self.engine = Engine(*args, **kwargs)
+
         super().__init__(*args, **kwargs)
 
     def reply(self, statement, context=None):
         """ Suggest responses to a user statement string with [(score, reply_string)..]"""
-        if context is None:
-            context = {}
-        statement = statement or ''
-        # response = self.engine.run(statement, **kwargs)
-        response = self.engine.run(**context)
+        context_changes = dict(context or {})
+        context_changes['user_text'] = (statement or '')
+
+        response = self.engine.run(**context_changes)
         responses = [(1.0,
                       response.get('bot_text',
                                    'ERROR: not bot_text returned from v3.Engine()')
