@@ -11,9 +11,9 @@ from time import time
 from sklearn.linear_model import SGDClassifier
 from numpy import argmax, mean, append
 from qary.skills.base import BotReply
-from qary.constants import DATA_DIR
+from qary.config import DATA_DIR
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 class State(Enum):
