@@ -4,12 +4,12 @@ import logging
 import numpy as np
 import transformers
 
-from qary.constants import CLI_ARGS
+from qary.config import CLI_ARGS
 from qary.skills.base import BotReply
 from qary.skills.base import ContextBaseSkill
 
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 STOP_WIKI_PROBABILITY = .4
 
