@@ -4,7 +4,7 @@ import logging
 
 from qary.skills import qa
 
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 STOP_WIKI_PROBABILITY = .4
 
