@@ -5,12 +5,12 @@ import pandas as pd
 import numpy as np
 import sqlite3
 
-from qary.constants import BASE_DIR
+from qary.config import BASE_DIR
 
 from git import Repo, InvalidGitRepositoryError, NoSuchPathError
 
 import logging
-log = logging.getLogger(__name__)
+log = logging.getLogger('qary')
 
 
 FIREFOX_PATHS = [
